@@ -3,7 +3,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 136 2012-01-02 19:40:38Z saturn $
+# $Id: smsconEditorMain.py 148 2012-01-11 22:56:09Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.9.11-1'
+Version = '0.9.12-1'
 
 import os
 import sys
@@ -146,47 +146,48 @@ def CopyMainToEditConfig():
     Make a copy of the main configuration for safe editing.
     @return bool Success indicator (may terminate app on hack detection).
     '''  
-
-    def tryCopy():
-        
-       global editConf
-       
-       if os.WEXITSTATUS(os.system('sudo smscon -export! "%s"' % editConf.Filename)) == 0:
-          return True
-       msg1 = 'Loading active settings failed.'
-
-       if os.WEXITSTATUS(os.system('sudo smscon -init')) == 0:
-          msg2 = '\nActivated initial settings.'
-       else:
-          msg2 = '\nActivating initial settings failed.'
-
-       if not IsFileReadable(editConf.Filename):   # os.path.isfile() checks existence only, not accessibility
-          showMessage(msg1+msg2)
-          return False
-       # Try to restore recent pre-edit settings.
-       return EditConfigAndApply(None,
-          startMessage    = None,
-          successMessage  = msg1 + '\nActivated recent edit settings.',
-          errorMessage    = msg1 + '\nFailed to activate recent edit settings.' + msg2,
-          )
-
-    ok = tryCopy() or tryCopy() # 2nd call may succeed if 1st could activate some of recent edit settings.
-
     global editConf
-    if not editConf.load():
-       if not editConf.needsUpgrade():
-          message = 'Failed to read SMSCON settings.\n%s' % FatalHelp
-          showMessage(message)
-          sys.exit(1)
-       if not editConf.upgrade():
-          message = 'Failed to upgrade SMSCON settings.\n%s' % FatalHelp
-          showMessage(message)
-          sys.exit(1)
+
+    # Export current settings:
+
+    try:     os.remove(editConf.Filename)
+    except:  pass 
+
+    ok = os.WEXITSTATUS(os.system('sudo smscon -export! "%s"' % editConf.Filename)) == 0
+
+    if IsFileReadable(editConf.Filename):
+       # File exists and ok indicates if content is valid. We load it in any case
+       # and apply the fixes and upgrades to editConf below.
+       pass
+    else:
+       message = 'Loading active settings failed.'
+       if os.WEXITSTATUS(os.system('sudo smscon -init!')) == 0:
+           message = message + '\nActivated initial settings.'
+       else:
+           message = message + '\nActivating initial settings failed.'
+       showMessage(message)
+       # In any case after init, try export again:
+       ok = os.WEXITSTATUS(os.system('sudo smscon -export! "%s"' % editConf.Filename)) == 0
+
+    # Load exported file. Check for errors and upgrade settings. 
+
+    ok = editConf.load()
+    if not ok:
+       message = 'Failed to load SMSCON settings.'
+       if editConf.needsUpgrade():
+          ok = editConf.upgrade()
+          if not ok:
+             message = 'Failed to upgrade SMSCON settings.'
+       elif editConf.create(Force = True):
+          message = message + '\nUsing initial settings.'
+       else:
+          message = message + '\nUsing initial settings failed.\n%s' % FatalHelp
+
     if ok:
        message = 'Successfully loaded SMSCON settings.'
        showQuickMessage(message)
     else:
-       message = 'Enforcedly loaded SMSCON settings.\nPlease check them all. Some seem to be invalid.'
+       message = message + '\nPlease check them all.'
        showMessage(message)
     return True
 
@@ -936,10 +937,10 @@ class smsconEditorPasswordChange(QtGui.QDialog):
           NewPassword = InitialPassword
 
        try:
-          try:
-             os.remove(PassFile)
-          except:
-             pass 
+          os.remove(PassFile)
+       except:
+          pass 
+       try:
           time.sleep(1)
           os.system('sudo "%s" %s "%s"' % (os.path.join(AppPath, 'smsconEditorCreatePass'),   # sudo wants abs path
                                            shellArg(NewPassword),
